@@ -1,10 +1,58 @@
+# BEGIN BPS TAGGED BLOCK {{{
+#
+# COPYRIGHT:
+#
+# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
+#                                          <sales@bestpractical.com>
+#
+# (Except where explicitly superseded by other copyright notices)
+#
+#
+# LICENSE:
+#
+# This work is made available to you under the terms of Version 2 of
+# the GNU General Public License. A copy of that license should have
+# been provided with this software, but in any event can be snarfed
+# from www.gnu.org.
+#
+# This work is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+# 02110-1301 or visit their web page on the internet at
+# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html.
+#
+#
+# CONTRIBUTION SUBMISSION POLICY:
+#
+# (The following paragraph is not intended to limit the rights granted
+# to you to modify and distribute this software under the terms of
+# the GNU General Public License and is only of importance to you if
+# you choose to contribute your changes and enhancements to the
+# community by submitting them to Best Practical Solutions, LLC.)
+#
+# By intentionally submitting any modifications, corrections or
+# derivatives to this work, or any other work intended for use with
+# Request Tracker, to Best Practical Solutions, LLC, you confirm that
+# you are the copyright holder for those contributions and you grant
+# Best Practical Solutions,  LLC a nonexclusive, worldwide, irrevocable,
+# royalty-free, perpetual, license to use, copy, create derivative
+# works based on those contributions, and sublicense and distribute
+# those contributions and any derivatives thereof.
+#
+# END BPS TAGGED BLOCK }}}
+
 use 5.008003;
 use warnings;
 use strict;
 
 package RT::Extension::ExternalStorage;
 
-our $VERSION = '0.51';
+our $VERSION = '0.55';
 
 use Digest::SHA qw//;
 
@@ -165,7 +213,15 @@ package RT::ObjectCustomFieldValue;
 
 sub StoreExternally {
     my $self = shift;
-    return 1 if $self->CustomFieldObj->Type eq "Binary";
+    my $type = $self->CustomFieldObj->Type;
+
+    return 1 if $type eq "Binary";
+
+    if ($type eq "Image") {
+        my $length = length($self->LargeContent || '');
+        return 1 if $length > 10 * 1024 * 1024;
+    }
+
     return 0;
 }
 
@@ -179,9 +235,11 @@ sub StoreExternally {
     } elsif ($type =~ m{^(text|message)/}) {
         # If textual, we only store externally if it's _large_ (> 10M)
         return 1 if $self->ContentLength > 10 * 1024 * 1024;
+        return 0;
     } elsif ($type =~ m{^image/}) {
         # Ditto images, which may be displayed inline
         return 1 if $self->ContentLength > 10 * 1024 * 1024;
+        return 0;
     } else {
         return 1;
     }
@@ -203,7 +261,7 @@ or via the web at
 
 =head1 COPYRIGHT
 
-This extension is Copyright (C) 2009-2014 Best Practical Solutions, LLC.
+This extension is Copyright (C) 2009-2015 Best Practical Solutions, LLC.
 
 This is free software, licensed under:
 
